#!/bin/sh


prompt()
{
	if test $NONINTERACTIVE; then
		return 0
	fi

	# BASH echo -ne "$*" >&2
	echo -n "$*" >&2
	read CMD rest
	return 0
}

getyn()
{
	if test $NONINTERACTIVE; then
		return 0
	fi

	while prompt "$* (y/n) "
	do	case $CMD in
			[yY])	return 0
				;;
			[nN])	return 1
				;;
			*)	echo -e "\nPlease answer y or n" >&2
				;;
		esac
	done        
}


build_tg3()
{
 	cd $HOME/tg3
	echo
	eval "make clean"
	eval "make | tee make.out" 
	if [ $? -ne 0 ]; then
    	echo
		echo "Error: Failed to compile Broadcom (tg3) driver"
		echo "       Contact Sangoma Support: techdesk@sangoma.com"
		echo
		return 1
	fi

    make install
	depmod -a
	echo "Broadcom (tg3) driver build sucessful!"

	return 0
}


build_micrel()
{
 	cd $HOME/ksz884x-1.0.13 
	echo
	eval "make clean"
	eval "make | tee make.out" 
	if [ $? -ne 0 ]; then
    	echo
		echo "Error: Failed to compile Micrel (ksz884x-1.0.13) driver"
		echo "       Contact Sangoma Support: techdesk@sangoma.com"
		echo
		return 1
	fi

    make install
	depmod -a
	echo "Micrel (ksz884x-1.0.13) driver build sucessful!"

	return 0
}

################ MAIN #########################
clear

HOME=`pwd`

while [ 1 ]; 
do
	cmd=$1

	if [ "$cmd" = "" ]; then
        break;
	fi	

  	if [ $cmd = "silent" ]; then
		echo
		echo "Running in interactive mode all optios will be set to yes!"
    	 NONINTERACTIVE=1
	fi

	if [ $cmd = "help" ]; then
    	echo
		echo "Usage: $0 [silent|help]"
		echo
		exit 1
	fi

	shift
done

echo "===================================================="
echo "Checking for exising Broadcom and Micrel Drivers"
echo 
echo "Sangoma: D100 PCIe -> Broadcom Ethernet"
echo "Sangoma: D100 PCI  -> Micrel Ethernet"
echo "===================================================="

echo
echo "Detecting Broadcom (tg3) driver...."

eval "modprobe -l  | grep tg3 2> /dev/null > /dev/null"
if [ $? -ne 0 ]; then
    echo "Failed to detect Broadcom (tg3) Ethernet Driver"
	getyn "Would you like to install Broadcom (tg3) driver now?"
	if [ $? -eq 0 ]; then
		build_tg3	
        rc=$?
	fi
else
	rc=0
	echo "Broadcom (tg3) driver detected!"
fi

if [ $rc -eq 0 ]; then
	echo
	echo "Broadcom (tg3) driver installed and loaded!"
	eval "modprobe tg3"
fi

echo "===================================================="

echo
echo "Detecting  Micrel (ks8842_pci) driver...."

rc=1

eval "modprobe -l  | grep ks8842_pci 2> /dev/null > /dev/null"
if [ $? -ne 0 ]; then
    echo "Failed to detect Micrel (ks8842_pci) Ethernet Driver"
	getyn "Would you like to install Micrel (ks8842_pci) driver now?"
	if [ $? -eq 0 ]; then
		build_micrel
        rc=$?
	fi
else
	rc=0
	echo "Micrel (ks8842_pci) driver detected!"
fi

if [ $rc -eq 0 ]; then
	echo
	echo "Micrel (ks8842_pci) driver installed and loaded!"
	eval "modprobe ks8842_pci"
fi    

echo
echo "===================================================="

exit 0

